@@ -160,35 +160,35 @@ Net::SSLGlue::LWP - proper certificate checking for https in LWP
 =head1 DESCRIPTION
 
 L<Net::SSLGlue::LWP> modifies L<Net::HTTPS> and L<LWP::Protocol::https> so that
-L<Net::HTTPS> is forced to use L<IO::Socket::SSL> instead of L<Crypt::SSLeay>
+L<Net::HTTPS> is forced to use L<IO::Socket::SSL> instead of L<Crypt::SSLeay>,
 and that L<LWP::Protocol::https> does proper certificate checking using the
 C<http> SSL_verify_scheme from L<IO::Socket::SSL>.
 
-Because L<LWP> does not have a mechanism to forward arbitrary parameter for
+Because L<LWP> does not have a mechanism to forward arbitrary parameters for
 the construction of the underlying socket these parameters can be set globally
-when including the package or with local settings of the
+when including the package, or with local settings of the
 C<%Net::SSLGlue::LWP::SSLopts> variable.
 
-All of the C<SSL_*> parameter from L<IO::Socket::SSL> can be used, especially
-the following parameters are useful:
+All of the C<SSL_*> parameter from L<IO::Socket::SSL> can be used; the
+following parameters are especially useful:
 
 =over 4
 
 =item SSL_ca_path, SSL_ca_file
 
 Specifies the path or a file where the CAs used for checking the certificates
-are located. Typical for UNIX systems is L</etc/ssl/certs>.
+are located. This is typically L</etc/ssl/certs> on UNIX systems.
 
 =item SSL_verify_mode
 
-If set to 0 disabled verification of the certificate. By default it is 1 which
-means, that the peer certificate is checked.
+If set to 0, verification of the certificate will be disabled. By default
+it is set to 1 which means that the peer certificate is checked.
 
 =item SSL_verifycn_name
 
 Usually the name given as the hostname in the constructor is used to verify the
 identity of the certificate. If you want to check the certificate against
-another name you might specify it with this parameter.
+another name you can specify it with this parameter.
 
 =back
 
